/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.geronimo.samples.datacdinfo.beans;

import java.io.Serializable;
import java.util.Date;

import javax.persistence.*;

/**
 * Demo how to code JPA entity bean, including various JPA annotations:
 * NamedQueries, Id, JoinColumn
 * 
 *
 */

@Entity(name="DataCD")
@Table(name="DATACD_TABLE")
@NamedQueries( {        
   @NamedQuery(name = "DataCD.findByOwnerId", query = "SELECT cd FROM DataCD cd WHERE cd.owner.username = :ownername"),
   @NamedQuery(name = "DataCD.findByOwnerIdandCDLabel", query = "SELECT cd FROM DataCD cd WHERE cd.owner.username = :ownername and cd.cdLabel = :cdlabel"),
   @NamedQuery(name = "DataCD.deleteByOwnerId", query = "DELETE FROM DataCD cd WHERE cd.owner.username = :ownername"),
   @NamedQuery(name = "DataCD.getAllCDs", query = "SELECT cd FROM DataCD cd")
})
public class DataCDBean implements Serializable{
    /**
     * 
     */
    private static final long serialVersionUID = -7665259395127908808L;
    @Id
    @Column(name = "CDID")
    @GeneratedValue(strategy=GenerationType.AUTO)
    private Integer cdID;
    
    @JoinColumn(name = "OWNER_USERNAME")
    @ManyToOne(fetch=FetchType.EAGER, optional=false)
    private OwnerBean owner;
    
    @Column(name = "CDLABEL", nullable=false)
    private String cdLabel;
    
    @Column(name = "CDDESC")
    private String cdDescription;
    
    @Column(name = "CDARCHIVEDATE")
    private Date cdArchiveDate;
    
    @Column(name = "CDSIZE")
    private Integer cdSize;
    
    public DataCDBean(){
        
    }
    
    public DataCDBean(Integer cdID, String cdLabel,
            String cdDescription, Date cdArchiveDate, Integer cdSize) {
        super();
        this.cdID = cdID;
        this.cdLabel = cdLabel;
        this.cdDescription = cdDescription;
        this.cdArchiveDate = cdArchiveDate;
        this.cdSize = cdSize;
    }
    
    public String toString(){
        return "[cdID:" + this.getCdID()
                + " cdLabel:" + this.getCdLabel()
                + " cdDescription:" + this.getCdDescription()
                + " cdArchiveDate:" + this.getCdArchiveDate().toString()
                + " cdSize:" + this.getCdSize()
                + " Owner:" + this.getOwner().getUsername()
                + "]";
        
    }
    public Integer getCdID() {
        return cdID;
    }
    public void setCdID(Integer cdID) {
        this.cdID = cdID;
    }
    public OwnerBean getOwner() {
        return owner;
    }
    public void setOwner(OwnerBean owner) {
        this.owner = owner;
    }
    public String getCdLabel() {
        return cdLabel;
    }
    public void setCdLabel(String cdLabel) {
        this.cdLabel = cdLabel;
    }
    public String getCdDescription() {
        return cdDescription;
    }
    public void setCdDescription(String cdDescription) {
        this.cdDescription = cdDescription;
    }
    public Date getCdArchiveDate() {
        return cdArchiveDate;
    }
    public void setCdArchiveDate(Date cdArchiveDate) {
        this.cdArchiveDate = cdArchiveDate;
    }
    public Integer getCdSize() {
        return cdSize;
    }
    public void setCdSize(Integer cdSize) {
        this.cdSize = cdSize;
    }
    
    
    

}
