/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.geronimo.samples.datacdinfo.core;

import java.util.ArrayList;
import java.util.List;

import javax.annotation.security.RolesAllowed;
import javax.ejb.Stateful;

import org.apache.geronimo.samples.datacdinfo.beans.DataCDBean;
import org.apache.geronimo.samples.datacdinfo.beans.OwnerBean;

import javax.persistence.EntityManager;
import javax.persistence.PersistenceContextType;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;

/**
 * Session Bean implementation class DataCDInfoAdmin
 * 
 * Demo how to use security annotations and container-managed extended-scoped persistence context,
 * and using JTA transaction.
 */
//@Stateful(name="ejb/DataCDInfoAdmin")
@Stateful
public class DataCDInfoAdmin implements DataCDInfoAdminLocal {
    
    @PersistenceContext(unitName="DataCDInfoUnit", type = PersistenceContextType.EXTENDED)    
    private EntityManager em;

    /**
     * Default constructor. 
     */
    public DataCDInfoAdmin() {
        // do nothing
    }
    
    @RolesAllowed("superadmin")
    public String findpasswd(String username) {
        OwnerBean owner = em.find(OwnerBean.class, username);
        String passwd = owner.getPassword();
        return passwd;
    }
    
    @RolesAllowed("superadmin")
    public String[] listAllDataCDs() {
        ArrayList<String> allcdstring = new ArrayList<String>();
        Query query = em.createNamedQuery("DataCD.getAllCDs");
        List<DataCDBean> allcds = query.getResultList();
        for (DataCDBean cd : allcds){
            allcdstring.add(cd.toString());
        }
        
        String[] result = allcdstring.toArray(new String[0]);
        return result;
    }
    
    @RolesAllowed({"admin","superadmin"})
    public String[] listOwners() {
        ArrayList<String> allusers = new ArrayList<String>();
        List<Object> owners = new ArrayList<Object>();
        Query query = em.createNativeQuery("SELECT USERNAME FROM OWNER_TABLE");
        owners = query.getResultList(); 
        for (Object owner : owners ) {
            String ownername = owner.toString();
            allusers.add(ownername);
        }
        String[] result = allusers.toArray(new String[0]);
        return result;
    }

}
